Copyright (C) 2014-2019 H. Turgut Uyar <uyar@tekir.org>

Piculet is a module for extracting data from XML or HTML documents
using XPath queries. It consists of a `single source file`_
with no dependencies other than the standard library, which makes it very easy
to integrate into applications. It also provides a command line interface.

:PyPI: https://pypi.org/project/piculet/
:Repository: https://github.com/uyar/piculet
:Documentation: https://piculet.readthedocs.io/

Piculet has been tested with Python 2.7, Python 3.4+, and compatible
versions of PyPy. You can install the latest version using ``pip``::

    pip install piculet

.. _single source file: https://github.com/uyar/piculet/blob/master/piculet.py
